@@ -1,16 +1,16 @@
 #' Construct admixture proportion matrix for independent subpopulations
 #'
 #' This function constructs an admixture proportion matrix where every individuals is actually unadmixed (draws its full ancestry from a single intermediate subpopulation).
-#' The inputs are the vector of subpopulation labels \code{labs} for every individual (length \eqn{n}), and
-#' the length-\eqn{k} vector of unique subpopulations \code{subpops} in the desired order.
-#' If \code{subpops} is missing, the sorted unique subpopulations observed in \code{labs} is used.
+#' The inputs are the vector of subpopulation labels `labs` for every individual (length `n`), and
+#' the length-`k` vector of unique subpopulations `subpops` in the desired order.
+#' If `subpops` is missing, the sorted unique subpopulations observed in `labs` is used.
 #' This function returns the admixture proportion matrix, for each individual 1 for the column corresponding to its subpopulation, 0 otherwise.
 #'
-#' @param labs Length-\eqn{n} vector of subpopulation labels
-#' @param subpops Optional length-\eqn{k} vector of unique subpopulations in desired order.
-#' Stops if \code{subpops} does not contain all unique labels in \code{labs} (no error if \code{subpops} contains additional labels).
+#' @param labs Length-`n` vector of subpopulation labels
+#' @param subpops Optional length-`k` vector of unique subpopulations in desired order.
+#' Stops if `subpops` does not contain all unique labels in `labs` (no error if `subpops` contains additional labels).
 #'
-#' @return The \eqn{n \times k}{n-by-k} admixture proportion matrix.
+#' @return The `n`-by-`k` admixture proportion matrix.
 #' The unique subpopulation labels are given in the column names.
 #'
 #' @examples
@@ -30,14 +30,14 @@
 #' admix_proportions <- admix_prop_indep_subpops(labs, subpops)
 #'
 #' @export
-admix_prop_indep_subpops <- function(labs, subpops) {
-    if (missing(subpops)) {
-        # get unique list of subpopulations, sorted for maximum stability
-        subpops <- sort(unique(labs))
-    } else {
-        if (!all(labs %in% subpops))
-            stop("provided 'subpops' does not contain all labels in 'labs'!")
-    }
+admix_prop_indep_subpops <- function(
+                                     labs,
+                                     subpops = sort( unique( labs ) )
+                                     ) {
+    # check if subpops is provided but was inconsistent with labs
+    if ( !all( labs %in% subpops ) )
+        stop("provided `subpops` does not contain all labels in `labs`!")
+    
     n_ind <- length(labs) # number of individuals
     k_subpops <- length(subpops) # number of subpopulations
     admix_proportions <- matrix(0, nrow = n_ind, ncol = k_subpops) # initialize the desired admixture matrix
