@@ -1,17 +1,17 @@
 #' Draw genotypes from the admixture model
 #'
-#' Given the Individual-specific Allele Frequency (IAF) \eqn{\pi_{ij}} for locus \eqn{i} and individual \eqn{j}, genotypes are drawn binomially:
-#' \deqn{x_{ij}|\pi_{ij} \sim \mbox{Binomial}(2, \pi_{ij}).}
-#' Below \eqn{m} is the number of loci, \eqn{n} the number of individuals, and \eqn{k} the number of intermediate subpopulations.
-#' If an admixture proportion matrix \eqn{Q} is provided as the second argument, the first argument \eqn{P} is treated as the intermediate subpopulation allele frequency matrix and the IAF matrix is given by
-#' \deqn{P Q^T.}{P \%*\% t(Q).}
-#' However, in this case the IAF matrix is computed in parts only, never stored in full, greatly reducing memory usage.
-#' If \eqn{Q} is missing, then \eqn{P} is treated as the IAF matrix.
+#' Given the Individual-specific Allele Frequency (IAF) matrix `p_ind` for `m` loci (rows) and `n` individuals (columns), the genotype matrix `X` (same dimensions as `p_ind`) is drawn from the Binomial distribution equivalent to
+#' `X[ i, j ] <- rbinom( 1, 2, p_ind[ i, j ] )`,
+#' except the function is more efficient.
+#' If `admix_proportions` is provided as the second argument (a matrix with `n` individuals along rows and `k` intermediate subpopulations along the columns), the first argument `p_ind` is treated as the intermediate subpopulation allele frequency matrix (must be `m`-by-`k`) and the IAF matrix is equivalent to
+#' `p_ind %*% t( admix_proportions )`.
+#' However, in this case the function computes the IAF matrix in parts only, never stored in full, greatly reducing memory usage.
+#' If `admix_proportions` is missing, then `p_ind` is treated as the IAF matrix.
 #' 
-#' @param p_ind The \eqn{m \times n}{m-by-n} IAF matrix (if \code{admix_proportions} is missing) or the \eqn{m \times k}{m-by-k} intermediate subpopulation allele frequency matrix (if \code{admix_proportions} is present)
-#' @param admix_proportions The optional \eqn{n \times k}{n-by-k} admixture proportion matrix
+#' @param p_ind The `m`-by-`n` IAF matrix (if `admix_proportions` is missing) or the `m`-by-`k` intermediate subpopulation allele frequency matrix (if `admix_proportions` is present)
+#' @param admix_proportions The optional `n`-by-`k` admixture proportion matrix (to draw data from the admixture model using reduced memory, by not fully forming the IAF matrix)
 #'
-#' @return The \eqn{m \times n}{m-by-n} genotype matrix
+#' @return The `m`-by-`n` genotype matrix
 #'
 #' @examples
 #' # dimensions
@@ -101,6 +101,11 @@ draw_genotypes_admix <- function(p_ind, admix_proportions = NULL) {
                 # p_ind is (m, k)
                 # p_ind_j is length (m)
                 p_ind_j <- drop( p_ind %*% admix_proportions[ j, ] )
+                # due to limited numerical precision, `p_ind_j` values can go out of range, fix that if it happens (otherwise rbinom returns `NA`s)
+                if ( any( p_ind_j < 0 ) )
+                    p_ind_j[ p_ind_j < 0 ] <- 0
+                if ( any( p_ind_j > 1 ) )
+                    p_ind_j[ p_ind_j > 1 ] <- 1
                 # draw genotypes and store!
                 X[ , j ] <- stats::rbinom( m_loci, 2, p_ind_j )
             }
@@ -112,6 +117,11 @@ draw_genotypes_admix <- function(p_ind, admix_proportions = NULL) {
                 # admix_proportions is (n, k)
                 # p_ind_i is length (n)
                 p_ind_i <- drop( admix_proportions %*% p_ind[ i, ] )
+                # due to limited numerical precision, `p_ind_i` values can go out of range, fix that if it happens (otherwise rbinom returns `NA`s)
+                if ( any( p_ind_i < 0 ) )
+                    p_ind_i[ p_ind_i < 0 ] <- 0
+                if ( any( p_ind_i > 1 ) )
+                    p_ind_i[ p_ind_i > 1 ] <- 1
                 # draw genotypes and store!
                 X[ i, ] <- stats::rbinom( n_ind, 2, p_ind_i )
             }
